@@ -181,6 +181,8 @@ class EdgeFit:
         compnb=Pmw.NoteBook(compwin)
         if sys.platform == 'win32':
             compnb.configure(hull_background="SystemButtonFace")
+        else:
+            compnb.configure(hull_background="#d4d0c8")
         compnb.recolorborders()        
         compnb.pack(fill="both",expand=1)
         #file components page
@@ -221,6 +223,8 @@ class EdgeFit:
         self.compdes=Pmw.NoteBook(sf,tabpos=None)
         if sys.platform == 'win32':
             self.compdes.configure(hull_background="SystemButtonFace")
+        else:
+            self.compdes.configure(hull_background="#d4d0c8")
         self.compdes.recolorborders()
         self.compwidlist=[]
         self.compwidref={}
@@ -265,6 +269,8 @@ class EdgeFit:
         self.funcdes=Pmw.NoteBook(sf,tabpos=None)
         if sys.platform == 'win32':
             self.funcdes.configure(hull_background="SystemButtonFace")
+        else:
+            self.funcdes.configure(hull_background="#d4d0c8")
         self.funcdes.recolorborders()
         self.funcwidlist=[]
         self.funcwidref={}
