@@ -216,7 +216,7 @@ class PCAMain:
         tarwin.grid(row=16,column=4,columnspan=2,rowspan=10,sticky=W+E+N+S)
         l=Label(tarwin,text='Target Transform',relief=RAISED,bd=2)
         l.pack(side=TOP,fill=X,padx=2,pady=4)
-        self.targetfile=Tix.FileEntry(tarwin,label="Target File: ")
+        self.targetfile=Tix.FileEntry(tarwin,label="Target File: ",dialogtype="tk_getOpenFile")
         self.targetfile.pack(side=TOP,padx=2,pady=7)
         b=Button(tarwin,text="Do Target Transform",command=self.dotargettrans,bg='red',fg='white')
         b.pack(side=TOP,fill=X,padx=15,pady=10)    
@@ -752,7 +752,10 @@ class PCAMain:
         for i in range(len(eval)):
             ecsum.append(sum(eval[0:i+1]))
             temp=sum(evalsq[i+1:len(eval)])
-            div=(len(eval)-(i+1))**5
+            try:
+                div=(len(eval)-(i+1))**5
+            except:
+                div=0
             if div!=0:
                 rateind.append(sqrt(temp/div))
             else:
