@@ -146,7 +146,7 @@ class Main:
         self.dodt=IntVar()
         cb=Checkbutton(dtwin,text="Do the deatime correction?",variable=self.dodt,anchor=W,command=self.dodeadtime)
         cb.pack(side=TOP,padx=2,pady=2)
-        self.dtfile=Tix.FileEntry(dtwin,label="Deadtime File: ")
+        self.dtfile=Tix.FileEntry(dtwin,label="Deadtime File: ",dialogtype="tk_getOpenFile")
         self.dtfile.pack(side=TOP,padx=2,pady=2)
         b=Button(dtwin,text="New DT file",width=20,command=self.getnewdtfile,bg='darkseagreen4',fg='ivory')
         b.pack(side=TOP,padx=2,pady=5)
